@@ -23,9 +23,14 @@
 #define _DEVNAME_H_
 
 #include <sys/types.h>
+#include <sys/sysmacros.h>
+#include <sys/stat.h>
 
-#define	Root_RAM0	makedev(1,0)
-#define Root_NFS	makedev(0,255)
+#define	Root_RAM0	__makedev(1,0)
+
+/* These device numbers are only used internally */
+#define Root_NFS	__makedev(0,255)
+#define Root_MTD	__makedev(0,254)
 
 #define BUF_SZ		65536
 #define TMPBUF_SZ	512
